/*
 * Copyright (c) 2013 - 2014, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 * All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NXP "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NXP OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "adc_pal_cfg.h"
#include "adc_irq.h"

/*******************************************************************************
 * Code
 ******************************************************************************/

/* Define default interrupt handlers for ADC instances.
 * Default interrupt handlers already declared in startup files. */

#if defined(ADC_PAL_S32K1xx)

#if (NUMBER_OF_ADC_PAL_INSTANCES >= 1u)
void ADC0_IRQHandler(void)
{
    ADC_S32K1xx_IrqHandler(ADC_PAL_INSTANCE_0);
}
#endif /* (NUMBER_OF_ADC_PAL_INSTANCES >= 1u) */

#if (NUMBER_OF_ADC_PAL_INSTANCES >= 2u)
void ADC1_IRQHandler(void)
{
    ADC_S32K1xx_IrqHandler(ADC_PAL_INSTANCE_1);
}
#endif /* (NUMBER_OF_ADC_PAL_INSTANCES >= 2u) */

#endif /* defined(ADC_PAL_S32K1xx) */


#if defined(ADC_PAL_MPC574xC_G_R)

/* For HW triggered groups with a single conversion */
void BCTU_ConvUpdate_IRQHandler(void)
{
    uint8_t adcIdx = 0u;
    const adc_pal_instance_t instance = ADC_PAL_INSTANCE_0;

    for(adcIdx = 0u; adcIdx < FEATURE_BCTU_NUM_ADC; adcIdx++)
    {
        /* ADC PAL doesn't trigger conversions in parallel on multiple ADCs,
         * so only one ADC should have new data available. */
        if(BCTU_DRV_GetStatusFlag(instance, adcIdx, BCTU_FLAG_NEW_DATA_AVAILABLE))
        {
            ADC_MPC574xC_G_R_HwTrigIrqHandler(instance, adcIdx);

            break;
        }
    }
}

/* For HW triggered groups with multiple conversions */
void BCTU_ListLast_IRQHandler(void)
{
    uint8_t adcIdx = 0u;
    const adc_pal_instance_t instance = ADC_PAL_INSTANCE_0;

    for(adcIdx = 0u; adcIdx < FEATURE_BCTU_NUM_ADC; adcIdx++)
    {
        /* ADC PAL doesn't trigger conversions in parallel on multiple ADCs,
         * so only one ADC should have new data available. */
        if(BCTU_DRV_GetStatusFlag(instance, adcIdx, BCTU_FLAG_LIST_LAST_CONV))
        {
            ADC_MPC574xC_G_R_HwTrigIrqHandler(instance, adcIdx);

            break;
        }
    }
}

void ADC0_EOC_IRQHandler(void)
{
    ADC_MPC574xC_G_R_SwTrigIrqHandler(ADC_PAL_INSTANCE_0, 0u);
}

void ADC1_EOC_IRQHandler(void)
{
    ADC_MPC574xC_G_R_SwTrigIrqHandler(ADC_PAL_INSTANCE_0, 1u);
}

#endif /* defined(ADC_PAL_MPC574xC_G_R) */


/*******************************************************************************
 * EOF
 ******************************************************************************/
