/*
 * Copyright 2017 NXP
 * All rights reserved.
 *
 * THIS SOFTWARE IS PROVIDED BY NXP "AS IS" AND ANY EXPRESSED OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL NXP OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PAL_mapping_H
#define PAL_mapping_H
#include "device_registers.h"
/*
 * Define the available instances for SPI functionality
 */
#if (defined(CPU_S32K144HFT0VLLT) || defined(CPU_S32K144LFT0MLLT) || defined(CPU_S32K146) || defined(CPU_S32K148))
/*
 * @brief Define instances for S32K144 and S32K148 (LPSPI and FlexIO)
 * Implements : spi_instance_t_Class
 */

typedef enum
{
    SPI_OVER_LPSPI0_INSTANCE = 0U,
    SPI_OVER_LPSPI1_INSTANCE = 1U,
    SPI_OVER_LPSPI2_INSTANCE = 2U,
    SPI_OVER_FLEXIO0_INSTANCE = 3U, /* This is a virtual SPI instance over FlexIO */
    SPI_OVER_FLEXIO1_INSTANCE = 4U, /* This is a virtual SPI instance over FlexIO */
} spi_instance_t;

/* Defines the index limits for all SPIs */
#define LPSPI_HIGH_INDEX 2U
#define FLEXIO_SPI_LOW_INDEX 3U
#define FLEXIO_SPI_HIGH_INDEX 4U
#endif

#if (defined(CPU_S32K142))
/*
 * @brief Define instances for S32K142 (LPSPI and FlexIO)
 * Implements : spi_instance_t_Class
 */

typedef enum
{
    SPI_OVER_LPSPI0_INSTANCE = 0U,
    SPI_OVER_LPSPI1_INSTANCE = 1U,
    SPI_OVER_FLEXIO0_INSTANCE = 2U, /* This is a virtual SPI instance over FlexIO */
    SPI_OVER_FLEXIO1_INSTANCE = 3U, /* This is a virtual SPI instance over FlexIO */
} spi_instance_t;

/* Defines the index limits for all SPIs */
#define LPSPI_HIGH_INDEX 1U
#define FLEXIO_SPI_LOW_INDEX 2U
#define FLEXIO_SPI_HIGH_INDEX 3U
#endif

#if (defined(CPU_S32K116))
/*
 * @brief Define instances for S32K116 (LPSPI and FlexIO)
 * Implements : spi_instance_t_Class
 */

typedef enum
{
    SPI_OVER_LPSPI0_INSTANCE = 0U,
    SPI_OVER_FLEXIO0_INSTANCE = 1U, /* This is a virtual SPI instance over FlexIO */
    SPI_OVER_FLEXIO1_INSTANCE = 2U, /* This is a virtual SPI instance over FlexIO */
} spi_instance_t;

/* On S32K144 and S32K116 are available 3 instances which supports SPI */
#define NUMBER_OF_SPI_PAL_INSTANCES 3U
/* Defines the index limits for all SPIs */
#define LPSPI_HIGH_INDEX 0U
#define FLEXIO_SPI_LOW_INDEX 1U
#define FLEXIO_SPI_HIGH_INDEX 2U
#endif

#if (defined(CPU_MPC5747C) || defined(CPU_MPC5748C) || defined(CPU_MPC5746G) || defined(CPU_MPC5747G) || defined(CPU_MPC5748G))
/*
 * @brief Define instances for MPC5747C, MPC5748C, MPC5746G, MPC5747G, MPC5748G (DSPI)
 * Implements : spi_instance_t_Class
 */
typedef enum
{
    SPI_OVER_DSPI0_INSTANCE = 0U,
    SPI_OVER_DSPI1_INSTANCE = 1U,
    SPI_OVER_DSPI2_INSTANCE = 2U,
    SPI_OVER_DSPI3_INSTANCE = 3U,
    SPI_OVER_SPI0_INSTANCE = 4U,
    SPI_OVER_SPI1_INSTANCE = 5U,
    SPI_OVER_SPI2_INSTANCE = 6U,
    SPI_OVER_SPI3_INSTANCE = 7U,
    SPI_OVER_SPI4_INSTANCE = 8U,
    SPI_OVER_SPI5_INSTANCE = 9U,
} spi_instance_t;
#endif

#if (defined(CPU_MPC5744B) || defined(CPU_MPC5745B) || defined(CPU_MPC5746B) || defined(CPU_MPC5744C) || defined(CPU_MPC5745C) || defined(CPU_MPC5746C))
/*
 * @brief Define instances for MPC5744B, MPC5745B, MPC5746B, MPC5744C, MPC5745C, MPC5746C (DSPI)
 * Implements : spi_instance_t_Class
 */
typedef enum
{
    SPI_OVER_DSPI0_INSTANCE = 0U,
    SPI_OVER_DSPI1_INSTANCE = 1U,
    SPI_OVER_DSPI2_INSTANCE = 2U,
    SPI_OVER_DSPI3_INSTANCE = 3U,
    SPI_OVER_SPI0_INSTANCE = 4U,
    SPI_OVER_SPI1_INSTANCE = 5U,
    SPI_OVER_SPI2_INSTANCE = 6U,
    SPI_OVER_SPI3_INSTANCE = 7U,
} spi_instance_t;

#endif

#if (defined(CPU_MPC5744P) || defined(CPU_MPC5743P) || defined(CPU_MPC5742P) || defined(CPU_MPC5741P))
/*
 * @brief Define instances for MPC5741P, MPC5742P, MPC5743P, MPC5744P (SPI)
 * Implements : spi_instance_t_Class
 */
typedef enum
{
    SPI_OVER_SPI0_INSTANCE = 0U,
    SPI_OVER_SPI1_INSTANCE = 1U,
    SPI_OVER_SPI2_INSTANCE = 2U,
    SPI_OVER_SPI3_INSTANCE = 3U,
} spi_instance_t;

#endif

#endif /* PAL_mapping_H */
